==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/usecase/impl/ExtendSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.usecase.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.usecase.Extend;
import io.ciera.tool.sql.ooaofooa.usecase.ExtendSet;
import io.ciera.tool.sql.ooaofooa.usecase.UseCaseAssociationSet;
import io.ciera.tool.sql.ooaofooa.usecase.impl.UseCaseAssociationSetImpl;

import java.util.Arrays;
import java.util.List;


public class ExtendSetImpl extends InstanceSet<ExtendSet,Extend> implements ExtendSet {

    // attributes
    @Override
    public void setAssoc_ID( UniqueId ref_Assoc_ID ) throws XtumlException {
        for ( Extend extend : this ) extend.setAssoc_ID( ref_Assoc_ID );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( Extend extend : this ) extend.setDescrip( m_Descrip );
    }


    // selections
    @Override
    public UseCaseAssociationSet R1210_is_a_UseCaseAssociation() throws XtumlException {
        UseCaseAssociationSet usecaseassociationset = new UseCaseAssociationSetImpl();
        for ( Extend extend : this ) usecaseassociationset.add( extend.R1210_is_a_UseCaseAssociation() );
        return usecaseassociationset;
    }


    @Override
    public Extend nullElement() {
        return ExtendImpl.EMPTY_EXTEND;
    }

    @Override
    public ExtendSet emptySet() {
      return new ExtendSetImpl();
    }

    @Override
    public ExtendSet value() {
        return this;
    }

    @Override
    public List<Extend> elements() {
        return Arrays.asList(toArray(new Extend[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/usecase/impl/ExtendSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.usecase.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.usecase.Extend;
import io.ciera.tool.sql.ooaofooa.usecase.ExtendSet;
import io.ciera.tool.sql.ooaofooa.usecase.UseCaseAssociationSet;
import io.ciera.tool.sql.ooaofooa.usecase.impl.UseCaseAssociationSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ExtendSetImpl extends InstanceSet<ExtendSet,Extend> implements ExtendSet {

    public ExtendSetImpl() {
    }

    public ExtendSetImpl(Comparator<? super Extend> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setAssoc_ID( UniqueId ref_Assoc_ID ) throws XtumlException {
        for ( Extend extend : this ) extend.setAssoc_ID( ref_Assoc_ID );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( Extend extend : this ) extend.setDescrip( m_Descrip );
    }


    // selections
    @Override
    public UseCaseAssociationSet R1210_is_a_UseCaseAssociation() throws XtumlException {
        UseCaseAssociationSet usecaseassociationset = new UseCaseAssociationSetImpl();
        for ( Extend extend : this ) usecaseassociationset.add( extend.R1210_is_a_UseCaseAssociation() );
        return usecaseassociationset;
    }


    @Override
    public Extend nullElement() {
        return ExtendImpl.EMPTY_EXTEND;
    }

    @Override
    public ExtendSet emptySet() {
      return new ExtendSetImpl();
    }

    @Override
    public ExtendSet emptySet(Comparator<? super Extend> comp) {
      return new ExtendSetImpl(comp);
    }

    @Override
    public ExtendSet value() {
        return this;
    }

    @Override
    public List<Extend> elements() {
        return Arrays.asList(toArray(new Extend[0]));
    }

}
